@@ -170,8 +170,8 @@ class iexCommon():
 
     # Step One
     # Execution of class is split into two parts so that changes to the url can be made halfway through
-    def pre_execute(self, query_params):
-        self.add_query_params_to_url(self, query_params=None)
+    def pre_execute(self, **query_params):
+        self.add_query_params_to_url(self, query_params)
 
     # Step Two
     # Final execution step where token is added and request is made.
