@@ -70,7 +70,7 @@ def collection(collectionType, collectionName, external=False, vprint=False):
 
 #   Company
 IEX_COMPANY_URL = prepend_iex_url('stock') + '{symbol}/company?'
-def company(symbol, external=False, vprint=False):
+def company(symbol, external=False, vprint=False, **query_params):
     """:return: Company data such as website, address, and description for the requested company.
 
     :param symbol: The ticker or symbol of the stock you would like to request.
